@@ -220,6 +220,13 @@ findErrors = function(ids = NULL, reg = getDefaultRegistry()) {
 }
 
 
+# used in waitForJobs: find jobs which are done or error
+.findTerminated = function(reg, ids = NULL) {
+  done = NULL
+  filter(reg$status, ids, c("job.id", "done"))[!is.na(done), "job.id"]
+}
+
+
 #' @export
 #' @rdname findJobs
 findOnSystem = function(ids = NULL, reg = getDefaultRegistry()) {
@@ -258,7 +265,7 @@ findExpired = function(ids = NULL, reg = getDefaultRegistry()) {
 
 .findExpired = function(reg, ids = NULL, batch.ids = getBatchIds(reg)) {
   submitted = done = batch.id = NULL
-  filter(reg$status, ids, c("job.id", "submitted", "done", "batch.id"))[!is.na(submitted) & is.na(done) & batch.id %nin% batch.ids$batch.id, "job.id"]
+  filter(reg$status, ids, c("job.id", "submitted", "done", "batch.id"))[!is.na(submitted) & is.na(done) & batch.id %chnin% batch.ids$batch.id, "job.id"]
 }
 
 #' @export
