@@ -21,7 +21,7 @@ resetJobs = function(ids = NULL, reg = getDefaultRegistry()) {
   cols = c("submitted", "started", "done", "error", "memory", "resource.id", "batch.id", "log.file", "job.hash")
   reg$status[ids, (cols) := list(NA_real_, NA_real_, NA_real_, NA_character_, NA_real_, NA_integer_, NA_character_, NA_character_, NA_character_), on = "job.id"]
   fns = getResultFiles(reg, ids)
-  file.remove(fns[file.exists(fns)])
+  file.remove.safely(fns)
 
   sweepRegistry(reg)
   invisible(ids)
