@@ -28,16 +28,16 @@ test_that("pm/socket", {
   expect_equal(nrow(findDone(reg = reg)), 4L)
 })
 
-test_that("pm/mpi", {
-  skip_on_os("mac")
-  skip_on_cran()
-  skip_if_not_installed("parallelMap")
-  skip_if_not_installed("snow")
-  skip_if_not_installed("Rmpi")
-  skip_on_travis()
-  if (reg$cluster.functions$name %chin% c("Parallel", "Socket"))
-    skip("Nested local parallelization not supported")
+# test_that("pm/mpi", {
+#   skip_on_os("mac")
+#   skip_on_cran()
+#   skip_if_not_installed("parallelMap")
+#   skip_if_not_installed("snow")
+#   skip_if_not_installed("Rmpi")
+#   skip_on_travis()
+#   if (reg$cluster.functions$name %chin% c("Parallel", "Socket"))
+#     skip("Nested local parallelization not supported")
 
-  submitAndWait(reg, ids = ids, resources = list(pm.backend = "mpi", ncpus = 2))
-  expect_equal(nrow(findDone(reg = reg)), 4)
-})
+#   submitAndWait(reg, ids = ids, resources = list(pm.backend = "mpi", ncpus = 2))
+#   expect_equal(nrow(findDone(reg = reg)), 4)
+# })
