@@ -11,14 +11,14 @@ test_that("sweepRegistry", {
 
   expect_data_table(reg$resources, nrow = 2)
   expect_character(list.files(dir(reg, "logs")), len = 2L)
-  expect_character(list.files(fp(reg$file.dir, "jobs"), pattern = "\\.rds$"), len = 1L + (array.jobs && reg$cluster.functions$store.job) * 2L)
+  expect_character(list.files(fp(reg$file.dir, "jobs"), pattern = "\\.rds$"), len = 1L + (array.jobs && reg$cluster.functions$store.job.collection) * 2L)
   expect_character(list.files(fp(reg$file.dir, "jobs"), pattern = "\\.job$"), len = (batchtools$debug && array.jobs) * 2L)
 
   expect_true(sweepRegistry(reg))
 
   expect_data_table(reg$resources, nrow = 1)
   expect_character(list.files(dir(reg, "logs")), len = 1L)
-  if (reg$cluster.functions$store.job)
+  if (reg$cluster.functions$store.job.collection)
     expect_character(list.files(fp(reg$file.dir, "jobs")), len = 0L)
   checkTables(reg)
 
